@@ -1,12 +1,20 @@
-from parcels import FieldSet, ParticleSet, ScipyParticle, JITParticle, Variable
-from parcels import AdvectionRK4, AdvectionEE, AdvectionRK45
-from parcels import timer
-from argparse import ArgumentParser
-import numpy as np
 import math
-import pytest
+from argparse import ArgumentParser
 from datetime import timedelta as delta
 
+import numpy as np
+import pytest
+
+from parcels import AdvectionEE
+from parcels import AdvectionRK4
+from parcels import AdvectionRK45
+from parcels import FieldSet
+from parcels import JITParticle
+from parcels import ParticleSet
+from parcels import ScipyParticle
+from parcels import timer
+from parcels import Variable
+
 
 ptype = {'scipy': ScipyParticle, 'jit': JITParticle}
 method = {'RK4': AdvectionRK4, 'EE': AdvectionEE, 'RK45': AdvectionRK45}
@@ -21,15 +29,9 @@ def stommel_fieldset(xdim=200, ydim=200):
     Ph.D. dissertation, University of Bologna
     http://amsdottorato.unibo.it/1733/1/Fabbroni_Nicoletta_Tesi.pdf
     """
-    # Set NEMO fieldset variables
-    depth = np.zeros(1, dtype=np.float32)
-    time = np.linspace(0., 100000. * 86400., 2, dtype=np.float64)
-
-    # Some constants
-    A = 100
-    eps = 0.05
-    a = 10000
-    b = 10000
+    a = 10000 * 1e3
+    b = 10000 * 1e3
+    scalefac = 0.05  # to scale for physically meaningful velocities
 
     # Coordinates of the test fieldset (on A-grid in deg)
     lon = np.linspace(0, a, xdim, dtype=np.float32)
@@ -37,42 +39,38 @@ def stommel_fieldset(xdim=200, ydim=200):
 
     # Define arrays U (zonal), V (meridional), W (vertical) and P (sea
     # surface height) all on A-grid
-    U = np.zeros((lon.size, lat.size, time.size), dtype=np.float32)
-    V = np.zeros((lon.size, lat.size, time.size), dtype=np.float32)
-    P = np.zeros((lon.size, lat.size, time.size), dtype=np.float32)
+    U = np.zeros((lon.size, lat.size), dtype=np.float32)
+    V = np.zeros((lon.size, lat.size), dtype=np.float32)
+    P = np.zeros((lon.size, lat.size), dtype=np.float32)
 
-    [x, y] = np.mgrid[:lon.size, :lat.size]
-    l1 = (-1 + math.sqrt(1 + 4 * math.pi**2 * eps**2)) / (2 * eps)
-    l2 = (-1 - math.sqrt(1 + 4 * math.pi**2 * eps**2)) / (2 * eps)
-    c1 = (1 - math.exp(l2)) / (math.exp(l2) - math.exp(l1))
-    c2 = -(1 + c1)
-    for t in range(time.size):
-        for i in range(lon.size):
-            for j in range(lat.size):
-                xi = lon[i] / a
-                yi = lat[j] / b
-                P[i, j, t] = A * (c1*math.exp(l1*xi) + c2*math.exp(l2*xi) + 1) * math.sin(math.pi * yi)
-        for i in range(lon.size-2):
-            for j in range(lat.size):
-                V[i+1, j, t] = (P[i+2, j, t] - P[i, j, t]) / (2 * a / (xdim-1))
-        for i in range(lon.size):
-            for j in range(lat.size-2):
-                U[i, j+1, t] = -(P[i, j+2, t] - P[i, j, t]) / (2 * b / (ydim-1))
+    beta = 2e-11
+    r = 1/(11.6*86400)
+    es = r/(beta*a)
+
+    for i in range(lon.size):
+        for j in range(lat.size):
+            xi = lon[i] / a
+            yi = lat[j] / b
+            P[i, j] = (1 - math.exp(-xi/es) - xi) * math.pi * np.sin(math.pi*yi)*scalefac
+            U[i, j] = -(1 - math.exp(-xi/es) - xi) * math.pi**2 * np.cos(math.pi*yi)*scalefac
+            V[i, j] = (math.exp(-xi/es)/es - 1) * math.pi * np.sin(math.pi*yi)*scalefac
 
     data = {'U': U, 'V': V, 'P': P}
-    dimensions = {'lon': lon, 'lat': lat, 'depth': depth, 'time': time}
+    dimensions = {'lon': lon, 'lat': lat}
     return FieldSet.from_data(data, dimensions, mesh='flat', transpose=True)
 
 
-def UpdateP(particle, fieldset, time, dt):
-    particle.p = fieldset.P[time, particle.lon, particle.lat, particle.depth]
+def UpdateP(particle, fieldset, time):
+    particle.p = fieldset.P[time, particle.depth, particle.lat, particle.lon]
 
 
-def stommel_example(npart=1, mode='jit', verbose=False, method=AdvectionRK4):
+def stommel_example(npart=1, mode='jit', verbose=False, method=AdvectionRK4,
+                    outfile="StommelParticle.nc", repeatdt=None, write_fields=True):
     timer.fieldset = timer.Timer('FieldSet', parent=timer.stommel)
     fieldset = stommel_fieldset()
-    filename = 'stommel'
-    fieldset.write(filename)
+    if write_fields:
+        filename = 'stommel'
+        fieldset.write(filename)
     timer.fieldset.stop()
 
     # Determine particle class according to mode
@@ -84,21 +82,21 @@ def stommel_example(npart=1, mode='jit', verbose=False, method=AdvectionRK4):
         p = Variable('p', dtype=np.float32, initial=0.)
         p_start = Variable('p_start', dtype=np.float32, initial=fieldset.P)
 
-    pset = ParticleSet.from_line(fieldset, size=npart, pclass=MyParticle,
-                                 start=(100, 5000), finish=(200, 5000), time=0)
+    pset = ParticleSet.from_line(fieldset, size=npart, pclass=MyParticle, repeatdt=repeatdt,
+                                 start=(10e3, 5000e3), finish=(100e3, 5000e3), time=0)
 
     if verbose:
         print("Initial particle positions:\n%s" % pset)
 
     # Execute for 30 days, with 1hour timesteps and 12-hourly output
-    runtime = delta(days=30)
+    runtime = delta(days=600)
     dt = delta(hours=1)
-    outputdt = delta(hours=12)
+    outputdt = delta(days=5)
     print("Stommel: Advecting %d particles for %s" % (npart, runtime))
     timer.psetinit.stop()
     timer.psetrun = timer.Timer('Pset_run', parent=timer.pset)
     pset.execute(method + pset.Kernel(UpdateP), runtime=runtime, dt=dt,
-                 moviedt=None, output_file=pset.ParticleFile(name="StommelParticle", outputdt=outputdt))
+                 moviedt=None, output_file=pset.ParticleFile(name=outfile, outputdt=outputdt))
 
     if verbose:
         print("Final particle positions:\n%s" % pset)
@@ -109,11 +107,12 @@ def stommel_example(npart=1, mode='jit', verbose=False, method=AdvectionRK4):
 
 
 @pytest.mark.parametrize('mode', ['jit', 'scipy'])
-def test_stommel_fieldset(mode):
+def test_stommel_fieldset(mode, tmpdir):
     timer.root = timer.Timer('Main')
     timer.stommel = timer.Timer('Stommel', parent=timer.root)
-    psetRK4 = stommel_example(1, mode=mode, method=method['RK4'])
-    psetRK45 = stommel_example(1, mode=mode, method=method['RK45'])
+    outfile = tmpdir.join("StommelParticle")
+    psetRK4 = stommel_example(1, mode=mode, method=method['RK4'], outfile=outfile, write_fields=False)
+    psetRK45 = stommel_example(1, mode=mode, method=method['RK45'], outfile=outfile, write_fields=False)
     assert np.allclose([p.lon for p in psetRK4], [p.lon for p in psetRK45], rtol=1e-3)
     assert np.allclose([p.lat for p in psetRK4], [p.lat for p in psetRK45], rtol=1e-3)
     err_adv = np.array([abs(p.p_start - p.p) for p in psetRK4])
@@ -138,12 +137,16 @@ Example of particle advection in the steady-state solution of the Stommel equati
                    help='Print particle information before and after execution')
     p.add_argument('-m', '--method', choices=('RK4', 'EE', 'RK45'), default='RK4',
                    help='Numerical method used for advection')
+    p.add_argument('-o', '--outfile', default='StommelParticle.nc',
+                   help='Name of output file')
+    p.add_argument('-r', '--repeatdt', default=None, type=int,
+                   help='repeatdt of the ParticleSet')
     args = p.parse_args()
 
     timer.args.stop()
     timer.stommel = timer.Timer('Stommel', parent=timer.root)
-    stommel_example(args.particles, mode=args.mode,
-                    verbose=args.verbose, method=method[args.method])
+    stommel_example(args.particles, mode=args.mode, verbose=args.verbose, method=method[args.method],
+                    outfile=args.outfile, repeatdt=args.repeatdt)
     timer.stommel.stop()
     timer.root.stop()
     timer.root.print_tree()
