@@ -1,3 +1,4 @@
+import functools
 from ctypes import c_double
 from ctypes import c_float
 from ctypes import c_int
@@ -179,6 +180,7 @@ class Grid(object):
     def computeTimeChunk(self, f, time, signdt):
         nextTime_loc = np.infty if signdt >= 0 else -np.infty
         periods = self.periods.value if isinstance(self.periods, c_int) else self.periods
+        prev_time_indices = self.time
         if self.update_status == 'not_updated':
             if self.ti >= 0:
                 if (time - periods*(self.time_full[-1]-self.time_full[0]) < self.time[0] or time - periods*(self.time_full[-1]-self.time_full[0]) > self.time[2]):
@@ -199,17 +201,24 @@ class Grid(object):
                 self.time = self.time_full
                 self.ti, _ = f.time_index(time)
                 periods = self.periods.value if isinstance(self.periods, c_int) else self.periods
-                if signdt == -1 and self.ti == 0 and (time - periods*(self.time_full[-1]-self.time_full[0])) == self.time[0]:
+                if signdt == -1 and self.ti == 0 and (time - periods*(self.time_full[-1]-self.time_full[0])) == self.time[0] and f.time_periodic:
                     self.ti = len(self.time)-2
                     periods -= 1
-
-                if self.ti > 0 and signdt == -1:
+                if signdt == -1 and self.ti > 0:
                     self.ti -= 1
                 if self.ti >= len(self.time_full) - 2:
                     self.ti = len(self.time_full) - 3
+
                 self.time = self.time_full[self.ti:self.ti+3]
                 self.tdim = 3
-                self.update_status = 'first_updated'
+                if prev_time_indices is None or len(prev_time_indices) != 3 or len(prev_time_indices) != len(self.time):
+                    self.update_status = 'first_updated'
+                elif functools.reduce(lambda i, j: i and j, map(lambda m, k: m == k, self.time, prev_time_indices), True) and len(prev_time_indices) == len(self.time):
+                    self.update_status = 'not_updated'
+                elif functools.reduce(lambda i, j: i and j, map(lambda m, k: m == k, self.time[:2], prev_time_indices[:2]), True) and len(prev_time_indices) == len(self.time):
+                    self.update_status = 'updated'
+                else:
+                    self.update_status = 'first_updated'
             if signdt >= 0 and (self.ti < len(self.time_full)-3 or not f.allow_time_extrapolation):
                 nextTime_loc = self.time[2] + periods*(self.time_full[-1]-self.time_full[0])
             elif signdt == -1 and (self.ti > 0 or not f.allow_time_extrapolation):
